@@ -2,7 +2,6 @@
 
 import datetime
 import i18n
-import i18n.en
 
 
 class TimeDelta(object):
@@ -23,10 +22,19 @@ class TimeDelta(object):
 _locales = {}
 
 
+class LocaleImportError(ImportError):
+    def __init__(self, locale, ex):
+        self.message = "Cannot load locale module \"i18n.%s\". Exception: %s." % (locale, ex)
+
+    def __str__(self):
+        return self.message
+
+
 class LocaleContext(object):
     __slots__ = ("locale",)
 
     def __init__(self, locale="en"):
+        self.locale = None
         self.set_locale(locale)
 
     def set_locale(self, locale):
@@ -39,7 +47,7 @@ class LocaleContext(object):
                     raise ValueError()
                 self.locale = locale
             except Exception, ex:
-                raise ValueError("locale")
+                raise LocaleImportError(locale, ex)
 
     def from_now(self, time, precision=1, from_utc=False):
         if isinstance(time, datetime.datetime):
@@ -75,16 +83,4 @@ def set_locale(locale):
 
 
 def from_now(datetime_or_timestamp, precision=1, from_utc=False):
-    return _locale.from_now(datetime_or_timestamp, precision=precision, from_utc=from_utc)
-
-
-if "__main__" == __name__:
-    import time
-
-    for language in ["en", "ru", "ro"]:
-        locale = LocaleContext(language)
-
-        now = int(time.time())
-        for i in xrange(now - 10000000, now + 10000000, 60):
-            print locale.from_now(i)
-
+    return _locale.from_now(datetime_or_timestamp, precision=precision, from_utc=from_utc)
\ No newline at end of file
