@@ -3,7 +3,7 @@
 from . import *
 
 forms = {
-    SECOND: ("a few seconds",),
+    SECOND: "a few seconds",
     MINUTE: ("a minute", "minutes"),
     HOUR: ("an hour", "hours"),
     DAY: ("a day", "days"),
@@ -14,10 +14,13 @@ forms = {
 
 class Locale(BaseLocale):
     def relative(self, target, number):
-        if number == 1:
-            return forms[target][0]
+        if target == SECOND:
+            return forms[SECOND]
         else:
-            return "%s %s" % (number, forms[target][1])
+            if number == 1:
+                return forms[target][0]
+            else:
+                return "%s %s" % (number, forms[target][1])
 
     def past(self, time):
         return "%s ago" % time
