@@ -3,7 +3,7 @@
 from . import *
 
 forms = {
-    SECOND: ("câteva secunde",),
+    SECOND: "câteva secunde",
     MINUTE: ("un minut", "minute"),
     HOUR: ("o oră", "ore"),
     DAY: ("o zi", "zile"),
@@ -14,10 +14,13 @@ forms = {
 
 class Locale(BaseLocale):
     def relative(self, target, number):
-        if number == 1:
-            return forms[target][0]
+        if target == SECOND:
+            return forms[SECOND]
         else:
-            return "%s %s" % (number, forms[target][1])
+            if number == 1:
+                return forms[target][0]
+            else:
+                return "%s %s" % (number, forms[target][1])
 
     def past(self, time):
         return "%s în urmă" % time
